/*
 Android Blink
 
 Receives commands from the control computer using the main serial port, reacts to commands and returns status information to
 the control computer via the same port. (N.B. Though developed for use with Android, will work perfectly well with PC/Mac.)
 
 IMPORTANT: To be recognized by the 'Communicator' software, the Arduino device must be fitted with either
            an ATmega16U2 or ATmega8U2 programmed as a USB-to-serial converter.
            The 'Communicator' software will not work with FTDI or Prolific Serial based boards.
 
  The circuit: 
 * Android 3.1 or above (or other) computer attached via USB cable to a suitable Uno or Mega.
 * Standard LED/resistor pair on Pin 13. 
 
 created 21 Nov 2012
 by G.White (Westy53)
 
 This example code is in the public domain.
 
*/

// Pin 13 has an LED connected on most Arduino boards.
// give it a name:
  int led = 13;
// Define flags
  boolean e_flag = false;  //LED flash: enabled or not
  boolean s_flag = false;  //Current status of LED: on/off
// Define loop counter
  long loopCount = 0;

void setup() {
  // initialize serial port:
  Serial.begin(9600);
  // initialize the digital pin as an output.
  pinMode(led, OUTPUT);     
}

void loop() {
  // read from port 0:
  if (Serial.available()) {
    char aChar = Serial.read();
    if (aChar == 49) {
      e_flag = true;               // Enable LED flash
      Serial.write("LED_ON");      // Feed back info to control computer
      delay(100);                  // Delay to allow control PC to process feedback
    }  
    else if (aChar == 48) {
      e_flag = false;              // Disable LED flash
      Serial.write("LEDOFF");     
      delay(100);
    }
    if ((e_flag == true) && (s_flag == false)){
      s_flag = true;
      digitalWrite(led, HIGH);     // turn the LED on
      Serial.write("LEDLIT");
      loopCount = 0;
    }
    else if ((e_flag == false) && (s_flag == true)){
      s_flag = false;
      digitalWrite(led, LOW);      // turn the LED off
      Serial.write("LEDDIM");
    }
  }
  //Flash loop: Increase max value for loopCount to lengthen flash period (Declared long so can cope up to 2,147,483,647)
  if ((e_flag == true) && (loopCount > 50000)){
    loopCount = 0;
    if (s_flag == true){
      s_flag= false;
      digitalWrite(led, LOW);      // turn the LED off
      Serial.write("LEDDIM");
    }
    else if (s_flag == false){
      s_flag = true;
      digitalWrite(led, HIGH);     // turn the LED on
      Serial.write("LEDLIT");
    }
  }
  else { 
    loopCount = loopCount ++;
  }
}
